==> exonmap_1.0.07.tar.gz: exonmap/man/splicing.index.Rd <==
\name{splicing.index}
\alias{splicing.index}

\title{ Find probesets involved in differential splicing for two treatments}
\description{
 Reads expression data and using its \code{\link[Biobase]{pData}}, 
 calculates splicing index for each probeset in exons of genes from the list. 
 The splicing index formula come from the Affy white
 paper "Alternative Transcript Analysis Methods for Exon Arrays".
}
\usage{
splicing.index(x, genes, group, members, vector.out=T, debug=0)
}

\arguments{
  \item{x}{eSet for which splicing is to be calculated }
  \item{genes}{ Vector of Ensembl gene names to check }
  \item{group}{ Group name from covdesc }
  \item{members}{Two treatments to be chosen from the group }
  \item{vector.out}{ Vector or tabular output }
  \item{debug}{ Debug level - 0 stands for no debug messages, verbosity increases with the level}
}
\value{
  A vector of values of slicing index for each probeset - the further from 0, the more significant splicing. 
  Or a table with names of genes, exon, probesets, expression and splicing index.
}
\details{Splicing index operates on expression values of probesets normalized 
with gene-level expression. The value of the index may have values from -1 to 1.}
\references{\url{ http://bioinformatics.picr.man.ac.uk/}}
\author{ Michal J Okoniewski }

\seealso{ \code{\link[exonmap]{splanova}}, \code{\link[Biobase]{pData}  }}
\keyword{ misc }
\examples{ 
  \dontrun{
    gg <- probeset.to.gene(c("2326780","2326822" ))
    spl.idx <-  splicing.index(x.rma, gg, "group", c("a","b"), debug=4)
  }
}

==> exonmap_1.4.3.tar.gz: exonmap/man/splicing.index.Rd <==
\name{splicing.index}
\alias{splicing.index}

\title{ Find probesets involved in differential splicing for two treatments}
\description{
 Reads expression data and using its \code{\link[Biobase]{pData}}, 
 calculates splicing index for each probeset in exons of genes from the list. 
 The splicing index formula come from the Affy white
 paper "Alternative Transcript Analysis Methods for Exon Arrays".
}
\usage{
splicing.index(x, genes, group, members, median.gene=TRUE, vector.out=TRUE, by.chip=FALSE)
}

\arguments{
  \item{x}{eSet for which splicing is to be calculated }
  \item{genes}{ Vector of Ensembl gene names to check }
  \item{group}{ Group name from covdesc }
  \item{members}{Two treatments to be chosen from the group }
  \item{median.gene}{ If FALSE, mean of exon probeset values is used for gene-level summary, instead of median. }
  \item{vector.out}{ Vector or tabular output }
  \item{by.chip}{ Type of the algorithm - gene average by chip, as in Affymetrix paper or by group members}
}
\value{
  A vector of values of splicing index for each probeset - the further
  from 0, the more significant the splicing. 
  Or a table with names of genes, exon, probesets, expression and splicing index.
  In the case of "by chip" algorithm, the results include si and pval slots with values 
  of splicing index and p-values of t-test between group members. 
}
\details{Splicing index operates on expression values of probesets normalized 
with gene-level expression. The value of the index may have values from -1 to 1.}
\references{\url{ http://bioinformatics.picr.man.ac.uk/}}
\author{ Michal J Okoniewski }

\seealso{ \code{\link[exonmap]{splanova}}, \code{\link[Biobase]{pData}  }}
\keyword{ misc }
\examples{ 
  \dontrun{
    gg <- probeset.to.gene(c("2326780","2326822" ))
    spl.idx <-  splicing.index(x.rma, gg, "group", c("a","b"))
  }
}
